;; Keyboard-centric user interface
(setq inhibit-startup-message t)
(scroll-bar-mode -1)
(tool-bar-mode -1)   
(menu-bar-mode -1)

(require 'package)
(add-to-list 'package-archives '("melpa" . "https://melpa.org/packages/") t)
;; Comment/uncomment this line to enable MELPA Stable if desired.  See `package-archive-priorities`
;; and `package-pinned-packages`. Most users will not need or want to do this.
;;(add-to-list 'package-archives '("melpa-stable" . "https://stable.melpa.org/packages/") t)
(package-initialize)


(column-number-mode 't) ; show current column in status bar
(set-fringe-mode 10)

;;;; Indent 4 spaces by default. Use the "BSD" style for C-like languages.
;;(setq c-default-style
;;      (quote ((java-mode . "java")
;;              (awk-mode . "awk")
;;              (other . "bsd")))
;;      c-basic-offset 4)

;; Use 4 spaces for one tab visually.
(setq tab-width 4)

(show-paren-mode t) ; highlight matching open and close parentheses
(global-hl-line-mode) ; highlight current line
(global-visual-line-mode t) ; wrap long lines
(setq split-window-preferred-function
  'visual-fill-column-split-window-sensibly) ; wrap at window boundary

(global-whitespace-mode) ; enable whitespace handling by default
(setq
  whitespace-style ; see (apropos 'whitespace-style)
  '(face ; viz via faces
    trailing ; trailing blanks visualized
    lines-tail ; lines beyond whitespace-line-column visualized
    space-before-tab
    space-after-tab
    newline ; lines with only blanks visualized
    indentation ; spaces used for indent when config wants tabs
    empty ; empty lines at beginning or end or buffer
    )
  whitespace-line-column 100) ; column at which whitespace-mode says the line is too long
;;(set-face-attribute 'default nil :font "JetBrains Mono" :height 150)

;; themes
(use-package doom-themes
  :init (load-theme 'doom-nord t)
  :init (doom-themes-org-config))
(setq disabled-command-function nil)
(setq inhibit-startup-screen t)
(setq visible-bell t)

;; Only y/n answers 
(defalias 'yes-or-no-p 'y-or-n-p)

;; Save what you enter into minibuffer prompts
(setq history-length 25)
(savehist-mode 1)

;; Remember and restore the last cursor location of opened files
(save-place-mode 1)

;; Backup

(setq version-control t     ;; Use version numbers for backups.
      kept-new-versions 10  ;; Number of newest versions to keep.
      kept-old-versions 0   ;; Number of oldest versions to keep.
      delete-old-versions t ;; Don't ask to delete excess backup versions.
      backup-by-copying t)  ;; Copy all files, don't rename them.
(setq vc-make-backup-files t)
(setq backup-directory-alist '(("" . "~/.emacs.d/backup")))
(defvar emacs-autosave-directory
  (concat user-emacs-directory "autosaves/")
  "This variable dictates where to put auto saves. It is set to a
  directory called autosaves located wherever your .emacs.d/ is
  located.")

;; Sets all files to be backed up and auto saved in a single directory.
(setq backup-directory-alist
      `((".*" . ,emacs-autosave-directory))
      auto-save-file-name-transforms
      `((".*" ,emacs-autosave-directory t)))


(setq calendar-week-start-day 1)


(use-package nix-mode
  :mode ("\\.nix\\'" . nix-mode)
  :hook (nix-mode . lsp-deferred))

(use-package magit)
(setq magit-fetch-modules-jobs 16); fetch 16 modules in parallel

(use-package which-key
  :init (which-key-mode)
  :config (setq which-key-idle-delay 0.5))

(autoload 'markdown-mode "markdown-mode"
   "Major mode for editing Markdown files" t)
(add-to-list 'auto-mode-alist
             '("\\.\\(?:md\\|markdown\\|mkd\\|mdown\\|mkdn\\|mdwn\\)\\'" . markdown-mode))

(autoload 'gfm-mode "markdown-mode"
   "Major mode for editing GitHub Flavored Markdown files" t)
(add-to-list 'auto-mode-alist '("README\\.md\\'" . gfm-mode))

(use-package org-caldav
    :ensure t
    :config
    (setq org-caldav-url "https://next20.produhost.net/remote.php/dav/calendars/alexandre")
    (setq org-caldav-calendars
         '((:calendar-id "alexandre-dri" :files ("~/Nextcloud/PRIVE/13_Org/agenda.org")
            :inbox "~/Nextcloud/PRIVE/13_Org/agenda-DRI.org")
       )
    )     
    (setq org-caldav-delete-org-entries 'never)
    (setq org-caldav-delete-calenda-entries 'never)
    (setq org-icalendar-timezone "Europe/Paris")
)

;; org-mode
(require 'org)
(require 'org-mouse)
(setq org-startup-folded t
      org-pretty-entities t
      org-hide-emphasis-markers t
      org-startup-with-inline-images t
      org-image-actual-width '(300))
;; files with ".org" open in org-mode
(add-to-list 'auto-mode-alist '("\\.org$" . org-mode))
(setq org-agenda-files '("~/Nextcloud/PRIVE/13_Org/journal"))
;;;;;;

;; Org-Roam basic configuration
  (setq org-directory (concat (getenv "HOME") "/Nextcloud/PRIVE/13_Org/notes"))

  (use-package org-roam
    :after org
    :init (setq org-roam-v2-ack t) ;; Acknowledge V2 upgrade
    :custom
    (org-roam-directory (file-truename org-directory))
    :config
    (org-roam-setup)
    :bind (("C-c n f" . org-roam-node-find)
           ("C-c n r" . org-roam-node-random)		    
           (:map org-mode-map
                 (("C-c n i" . org-roam-node-insert)
                  ("C-c n o" . org-id-get-create)
                  ("C-c n t" . org-roam-tag-add)
                  ("C-c n a" . org-roam-alias-add)
                  ("C-c n l" . org-roam-buffer-toggle)
                  ("C-c n o" . org-open-at-point)
		  ("C-M-i" . completion-at-point))))
	   (:map org-roam-dailies-map
         	  (("Y" . org-roam-dailies-capture-yesterday)
         	   ("T" . org-roam-dailies-capture-tomorrow)))
     :bind-keymap
     ("C-c n d" . org-roam-dailies-map)
     :config
     (require 'org-roam-dailies) ;; Ensure the keymap is available
     (org-roam-db-autosync-mode))


;; one file org
(defvar org-gtd-file "~/Nextcloud/PRIVE/13_Org/DRI.org")

;; Open DRI.org when I hit C-c g
(defun gtd ()
  "Open the GTD file."
  (interactive)
  (find-file org-gtd-file))
;; keybinding
(global-set-key "\C-cl" 'org-store-link)
(global-set-key "\C-ca" 'org-agenda)
(global-set-key "\C-cg" 'gtd)

;; This seems like a good basic set of keywords to start out with:

(setq org-todo-keywords '((type "TODO" "WAIT" "DONE")))

(setf org-todo-keyword-faces '(("TODO" . (:foreground "cyan" :background "steelblue" :bold t :weight bold))
			       ("WAIT" . (:foreground "yellow" :background "magenta2" :bold t :weight bold))
			       ("DONE" . (:foreground "gray50" :background "gray30"))))

;; tags
(setq org-tag-alist '(("DEVIS" . ?d) ("PROJETS" . ?p) ("CLIENT" . ?c) ("PROSPECT" . ?o) ("INTERNE" . ?i) ("AO" . ?a) ("PJ" . ?z))


(setq org-tag-faces
        '(
          ("DEVIS" . (:foreground "OrangeRed" :weight bold))
          ("PJ" . (:foreground "brightyellow" :weight bold))
          ("PROJET" . (:foreground "IndianRed1" :weight bold))
	  ("INTERNE" . (:foreground "LimeGreen" :weight bold))
	  ("CLIENT" . (:foreground "Orange" :weight bold))
	  ("PROSPECT" . (:foreground "MediumPurple3" :weight bold))
	  ("AO" . (:foreground "HotPink2" :weight bold))
	 )
)
;;; Org-journal
;; https://github.com/bastibe/org-journal
;; C-c C-j
(setq org-journal-date-prefix "#+TITLE: ")
(setq org-journal-time-prefix "* ")
(setq org-journal-date-format "%a, %Y-%m-%d")
(setq org-journal-file-format "%Y-%m-%d-journal.org")
(setq org-journal-dir "~/Nextcloud/PRIVE/13_Org/journal/")
(global-set-key "\C-cnj" 'org-journal-new-entry)
(require 'org-journal)
